@@ -2,18 +2,19 @@
 
 import logging
 from pathlib import Path
+from shutil import which
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 import numpy as np
 from jobflow.utils import ValueEnum
-from monty.os.path import which
 from pydantic import BaseModel, Field
 from pydantic.datetime_parse import datetime
 from pymatgen.command_line.bader_caller import bader_analysis_from_path
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.bandstructure import BandStructure
-from pymatgen.electronic_structure.dos import Dos
+from pymatgen.electronic_structure.core import OrbitalType
+from pymatgen.electronic_structure.dos import CompleteDos, Dos
 from pymatgen.io.vasp import (
     BSVasprun,
     Locpot,
@@ -49,7 +50,7 @@ __all__ = [
 ]
 
 
-_BADER_EXE_EXISTS = which("bader") or which("bader.exe")
+_BADER_EXE_EXISTS = True if (which("bader") or which("bader.exe")) else False
 
 
 class Status(ValueEnum):
@@ -138,6 +139,8 @@ class CalculationInput(BaseModel):
     structure: Structure = Field(
         None, description="Input structure for the calculation"
     )
+    is_hubbard: bool = Field(False, description="Is this a Hubbard +U calculation")
+    hubbards: Dict = Field(None, description="The hubbard parameters used")
 
     @classmethod
     def from_vasprun(cls, vasprun: Vasprun) -> "CalculationInput":
@@ -169,6 +172,8 @@ class CalculationInput(BaseModel):
             potcar_type=[s.split(" ")[0] for s in vasprun.potcar_symbols],
             parameters=dict(vasprun.parameters),
             lattice_rec=vasprun.initial_structure.lattice.reciprocal_lattice,
+            is_hubbard=vasprun.is_hubbard,
+            hubbards=vasprun.hubbards,
         )
 
 
@@ -354,6 +359,11 @@ class CalculationOutput(BaseModel):
         description="Electron-phonon displaced structures, generated by setting "
         "PHON_LMC = True.",
     )
+    dos_properties: Dict[str, Dict[str, Dict[str, float]]] = Field(
+        None,
+        description="Element- and orbital-projected band properties (in eV) for the DOS. "
+        "All properties are with respect to the Fermi level.",
+    )
     run_stats: RunStatistics = Field(
         None, description="Summary of runtime statistics for this calculation"
     )
@@ -443,6 +453,13 @@ class CalculationOutput(BaseModel):
             magmoms = [m["tot"] for m in outcar.magnetization]
             structure.add_site_property("magmom", magmoms)
 
+        # Parse DOS properties
+        dosprop_dict = (
+            _get_band_props(vasprun.complete_dos, structure)
+            if hasattr(vasprun, "complete_dos")
+            else {}
+        )
+
         elph_structures: Dict[str, List[Any]] = {}
         if elph_poscars is not None:
             elph_structures.update({"temperatures": [], "structures": []})
@@ -461,6 +478,7 @@ class CalculationOutput(BaseModel):
             epsilon_ionic=vasprun.epsilon_ionic or None,
             frequency_dependent_dielectric=freq_dependent_diel,
             elph_displaced_structures=elph_structures,
+            dos_properties=dosprop_dict,
             ionic_steps=vasprun.ionic_steps,
             locpot=locpot_avg,
             outcar=outcar_dict,
@@ -518,7 +536,7 @@ class Calculation(BaseModel):
         parse_dos: Union[str, bool] = False,
         parse_bandstructure: Union[str, bool] = False,
         average_locpot: bool = True,
-        run_bader: bool = SETTINGS.VASP_RUN_BADER and _BADER_EXE_EXISTS,
+        run_bader: bool = (SETTINGS.VASP_RUN_BADER and _BADER_EXE_EXISTS),
         strip_bandstructure_projections: bool = False,
         strip_dos_projections: bool = False,
         store_volumetric_data: Optional[
@@ -569,8 +587,9 @@ class Calculation(BaseModel):
         run_bader
             Whether to run bader on the charge density.
         strip_dos_projections : bool
-            Whether to strip the element and site projections from the density of states.
-            This can help reduce the size of DOS objects in systems with many atoms.
+            Whether to strip the element and site projections from the density of
+            states. This can help reduce the size of DOS objects in systems with many
+            atoms.
         strip_bandstructure_projections : bool
             Whether to strip the element and site projections from the band structure.
             This can help reduce the size of DOS objects in systems with many atoms.
@@ -612,7 +631,7 @@ class Calculation(BaseModel):
             vasp_objects[VaspObject.BANDSTRUCTURE] = bandstructure  # type: ignore
 
         bader = None
-        if run_bader and "chgcar" in output_file_paths:
+        if run_bader and VaspObject.CHGCAR in output_file_paths:
             suffix = "" if task_name == "standard" else f".{task_name}"
             bader = bader_analysis_from_path(dir_name, suffix=suffix)
 
@@ -755,3 +774,57 @@ def _parse_bandstructure(
         return bs
 
     return None
+
+
+def _get_band_props(
+    complete_dos: CompleteDos, structure: Structure
+) -> Dict[str, Dict[str, Dict[str, float]]]:
+    """
+    Calculate band properties from a CompleteDos object and Structure.
+
+    Parameters
+    ----------
+    complete_dos
+        A CompleteDos object.
+    structure
+        a pymatgen Structure object.
+
+    Returns
+    -------
+    Dict
+        A dictionary of element and orbital-projected DOS properties.
+    """
+    dosprop_dict: Dict[str, Dict[str, Dict[str, float]]] = {}
+    for el in structure.composition.elements:
+        el_name = el.name
+        dosprop_dict[el_name] = {}
+        for orb_type in [
+            OrbitalType.s,
+            OrbitalType.p,
+            OrbitalType.d,
+            OrbitalType.f,
+        ]:
+            orb_name = orb_type.name
+            if (
+                (el.block == "s" and orb_name in ["p", "d", "f"])
+                or (el.block == "p" and orb_name in ["d", "f"])
+                or (el.block == "d" and orb_name == "f")
+            ):
+                continue
+            dosprops = {
+                "filling": complete_dos.get_band_filling(band=orb_type, elements=[el]),
+                "center": complete_dos.get_band_center(band=orb_type, elements=[el]),
+                "bandwidth": complete_dos.get_band_width(band=orb_type, elements=[el]),
+                "skewness": complete_dos.get_band_skewness(
+                    band=orb_type, elements=[el]
+                ),
+                "kurtosis": complete_dos.get_band_kurtosis(
+                    band=orb_type, elements=[el]
+                ),
+                "upper_edge": complete_dos.get_upper_band_edge(
+                    band=orb_type, elements=[el]
+                ),
+            }
+            dosprop_dict[el_name][orb_name] = dosprops
+
+    return dosprop_dict
