@@ -104,7 +104,7 @@ class VaspInputSet(InputSet):
             if v is not None and (overwrite or not (directory / k).exists()):
                 with zopen(directory / k, "wt") as f:
                     if isinstance(v, Poscar):
-                        # write POSCAR with more signifcant figures
+                        # write POSCAR with more significant figures
                         f.write(v.get_string(significant_figures=16))
                     else:
                         f.write(v.__str__())
@@ -256,7 +256,7 @@ class VaspInputSetGenerator(InputSetGenerator):
         Tolerance for symmetry finding, used for line mode band structure k-points.
     auto_ispin
         If generating input set from a previous calculation, this controls whether
-        to disable magnetisation (ISPIN = 1) if the absoluate valuue of all magnetic
+        to disable magnetisation (ISPIN = 1) if the absolute value of all magnetic
         moments are less than 0.02.
     config_dict
         The config dictionary to use containing the base input set settings.
